/**
 *  GuileEngine
 * 
 *  Copyright (c) 2002 Stefan Urbanek
 *
 *  Written by: Stefan Urbanek <stefanurbanek@yahoo.fr>
 *  Date: 2002 Jan 13
 *
 *  This file is part of the StepTalk project.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02111, USA.
 *
 */

#import "GuileEngine.h"

#import <ScriptKit/Guile.h>
#import <StepTalk/StepTalk.h>

#import <Foundation/NSDebug.h>

@implementation GuileEngine
+ (void)initialize
{
    gstep_init();
    gstep_link_base();
    [GuileInterpreter initializeInterpreter];
}

- (BOOL)understandsCode:(NSString *)code
{
    [self notImplemented:_cmd];
    return NO;
}

- (id)  executeCode:(NSString *)sourceCode 
      inEnvironment:(STEnvironment *)env
{
    [self executeScript:sourceCode inEnvironment:env];
    return nil;
}

- (id) executeScript:(NSString *)sourceCode 
       inEnvironment:(STEnvironment *)env
{
    GuileInterpreter *interp = AUTORELEASE([[GuileInterpreter alloc] init]);
    GuileScript      *script = AUTORELEASE([[GuileScript alloc] init]);
    GuileSCM         *result;

    [script setUserDictionary:[env defaultObjectPool]];
    [script setDelegate:sourceCode];
    result = [interp executeScript:script];
    
    return [result objectValue];
}
@end
